==> vue-layout-builder-1.0.2.tgz: package/src/store/actions.js <==
export default {
  editContent(store, data) {
    if (store.state.elements[data.id]) {
      store.commit("updateElement", data);
    } else {
      store.commit("addElement", data);
    }

    store.commit("editContent", data);
    store.commit("setCurrentlyEditableContent", null);
    store.commit("setContentOverlayVisibility", false);
  },
  chooseElement(store, data) {
    store.commit("editContent", data);
    store.commit("setCurrentlyEditableContent", null);
    store.commit("setContentOverlayVisibility", false);
  },
  showContentOverlay(store, data) {
    store.commit("setCurrentlyEditableContent", data);
    store.commit("setContentOverlayVisibility", true);
  },
  closeContentOverlay(store) {
    store.commit("setCurrentlyEditableContent", null);
    store.commit("setContentOverlayVisibility", false);
  },
  save({ commit, state }) {
    const body = new FormData();
    body.append("sections", JSON.stringify(state.sections));

    fetch(state.saveUrl, {
      credentials: "include",
      method: "POST",
      body
    })
      .then(response => {
        if (response.ok) {
          response
            .json()
            .then(result => {
              if (result.success) {
                commit("success", result.message);
                if (result.config !== undefined) {
                  commit("resetConfig", result.config);
                }
              } else {
                commit("error", result.message);
              }
            })
            .catch(() => {
              commit("error", "Saving failed. Please try again.");
            });
        } else {
          commit("error", "Saving failed. Please try again.");
        }
      })
      .catch(() => {
        commit("error", "Saving failed. Please try again.");
      });
  }
};

==> vue-layout-builder-1.0.4.tgz: package/src/store/actions.js <==
export default {
  editContent(store, data) {
    if (store.state.elements[data.id]) {
      store.commit("updateElement", data);
    } else {
      store.commit("addElement", data);
    }

    store.commit("editContent", data);
    store.commit("setCurrentlyEditableContent", null);
    store.commit("setContentOverlayVisibility", false);
  },
  chooseElement(store, data) {
    store.commit("editContent", data);
    store.commit("setCurrentlyEditableContent", null);
    store.commit("setContentOverlayVisibility", false);
  },
  showContentOverlay(store, data) {
    store.commit("setCurrentlyEditableContent", data);
    store.commit("setContentOverlayVisibility", true);
  },
  closeContentOverlay(store) {
    store.commit("setCurrentlyEditableContent", null);
    store.commit("setContentOverlayVisibility", false);
  },
  save({commit, state}) {
    const body = new FormData();
    body.append(
      "sections",
      JSON.stringify(state.sections),
    );

    fetch(state.saveUrl, {
      credentials: "include",
      method: 'POST',
      body
    })
      .then((response) => {
        if (response.ok) {
          response
            .json()
            .then(result => {
              if (result.success) {
                commit('success', result.message);
                if (result.config !== undefined) {
                  commit('resetConfig', result.config);
                }
              } else {
                commit('error', result.message);
              }
            })
            .catch(() => {
              commit('error', result.message);
            });
        } else {
          commit('error', "Saving failed. Please try again.");
        }
      })
      .catch(() => {
        commit('error', "Saving failed. Please try again.");
      });
  },

};
